@@ -93,7 +93,8 @@ class ConfigurationParser(Parser):
                                 if storage_type == "http":
                                     url = storage.get("url")
                                     message = storage.get("message") or f"Failed rows have been sent to {url}"
-                                    self.configuration.sampler = HTTPSampler(url, message=message)
+                                    link_text = storage.get("link_text") or message
+                                    self.configuration.sampler = HTTPSampler(url, message=message, link_text=link_text)
                             elif self.configuration.soda_cloud and not disable_samples:
                                 self.configuration.sampler = SodaCloudSampler()
                             else:
@@ -138,8 +139,17 @@ class ConfigurationParser(Parser):
         port = None
         if "port" in config_dict:
             port = config_dict.get("port")
+        scheme = None
+        if "scheme" in config_dict:
+            port = config_dict.get("scheme")
         return SodaCloud(
-            api_key_id=api_key, api_key_secret=api_secret, host=host, token=None, port=port, logs=self.logs
+            api_key_id=api_key,
+            api_key_secret=api_secret,
+            host=host,
+            token=None,
+            port=port,
+            logs=self.logs,
+            scheme=scheme,
         )
 
     def parse_dbt_cloud_cfg(self, config_dict: dict):
