@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from soda.scan import Scan
 
 
@@ -6,14 +8,21 @@ class DataSourceUtils:
     EXPERIMENTAL: Utility API for DataSource and connections.
     """
 
-    def __init__(self, config_path: str):
+    def __init__(self, config_path: str | None = None, config_string: str | None = None):
         """
         All the features for config files (e.g. env vars) are supported.
-        :param config_path: The director path containing the data source config yaml files.
+        :param config_path: The directory path containing the data source config yaml files.
+        :param config_string: The data source config yaml string.
         """
-        self.config_path = config_path
         self._scan = Scan()
-        self._scan.add_configuration_yaml_files(self.config_path)
+        self.config_path = config_path
+        self.config_string = config_string
+
+        if config_path:
+            self._scan.add_configuration_yaml_files(self.config_path)
+
+        if config_string:
+            self._scan.add_configuration_yaml_str(self.config_string)
 
     def get_connection(self, data_source_name: str):
         """
