@@ -17,6 +17,7 @@ from soda.sodacl.metric_check_cfg import MetricCheckCfg
 
 KEY_HISTORIC_MEASUREMENTS = "historic_measurements"
 KEY_HISTORIC_CHECK_RESULTS = "historic_check_results"
+HISTORIC_MEASUREMENTS_LIMIT = 1000
 
 
 class AnomalyMetricCheck(MetricCheck):
@@ -27,7 +28,6 @@ class AnomalyMetricCheck(MetricCheck):
         partition: Partition | None = None,
         column: Column | None = None,
     ):
-
         try:
             super().__init__(
                 check_cfg=check_cfg,
@@ -51,10 +51,10 @@ class AnomalyMetricCheck(MetricCheck):
 
             self.historic_descriptors[KEY_HISTORIC_MEASUREMENTS] = HistoricMeasurementsDescriptor(
                 metric_identity=metric.identity,
-                limit=1000,
+                limit=HISTORIC_MEASUREMENTS_LIMIT,
             )
             self.historic_descriptors[KEY_HISTORIC_CHECK_RESULTS] = HistoricCheckResultsDescriptor(
-                check_identity=self.create_identity(), limit=3
+                check_identity=self.create_identity(), limit=HISTORIC_MEASUREMENTS_LIMIT
             )
             self.diagnostics = {}
             self.cloud_check_type = "anomalyDetection"
@@ -111,7 +111,7 @@ class AnomalyMetricCheck(MetricCheck):
             self.logs.error(f"{SODA_SCIENTIFIC_MISSING_LOG_MESSAGE}\n Original error: {e}")
             return
 
-        anomaly_detector = AnomalyDetector(historic_measurements, historic_check_results, self.logs)
+        anomaly_detector = AnomalyDetector(historic_measurements, historic_check_results, self.logs, metric_name)
         level, diagnostics = anomaly_detector.evaluate()
         assert isinstance(diagnostics, dict), f"Anomaly diagnostics should be a dict. Got a {type(diagnostics)} instead"
 
