@@ -1,10 +1,10 @@
+from __future__ import annotations
+
 from soda.execution.query.query import Query
 
 
 class SampleQuery(Query):
-    def __init__(
-        self, data_source_scan: "DataSourceScan", metric: "Metric", sample_type: str, sql: str, passing_sql: str
-    ):
+    def __init__(self, data_source_scan: DataSourceScan, metric: Metric, sample_type: str, sql: str):
         """
         :param sample_type: Eg 'failed_rows'
         """
@@ -15,7 +15,6 @@ class SampleQuery(Query):
             unqualified_query_name=f"{sample_type}[{metric.name}]",
             sql=sql,
             samples_limit=metric.samples_limit,
-            passing_sql=passing_sql,
         )
         self.metric = metric
 
