@@ -9,7 +9,6 @@ from soda.sampler.sample import Sample
 
 @dataclass
 class SampleContext:
-
     sample: Sample
     sample_name: str
     query: str
@@ -19,7 +18,7 @@ class SampleContext:
     scan: Scan
     logs: Logs
     samples_limit: int | None
-    passing_query: str | None
+    passing_sql: str | None
     check_name: str | None
 
     def get_scan_folder_name(self):
