@@ -17,6 +17,7 @@ class SampleRef:
         soda_cloud_file_id: str | None = None,
         message: str | None = None,
         link: str | None = None,
+        link_text: str | None = None,
     ):
         self.name: str = name
         self.schema = schema
@@ -26,6 +27,7 @@ class SampleRef:
         self.soda_cloud_file_id: str | None = soda_cloud_file_id
         self.message: str | None = message
         self.link: str | None = link
+        self.link_text: str = link_text
 
     def __str__(self) -> str:
         column_count = f"{len(self.schema.columns)}x" if self.schema else ""
@@ -41,6 +43,14 @@ class SampleRef:
     def is_persisted(self) -> bool:
         return self.type != self.TYPE_NOT_PERSISTED
 
+    def get_cloud_diagnostics_block(self) -> dict:
+        file_block = {
+            "type": "file",
+            "title": "Failed Rows",
+            "file": self.get_cloud_diagnostics_dict(),
+        }
+        return file_block
+
     def get_cloud_diagnostics_dict(self):
         column_dicts = [column.get_cloud_dict() for column in self.schema.columns] if self.schema else None
         sample_ref_dict = {
@@ -52,5 +62,10 @@ class SampleRef:
             sample_ref_dict["reference"] = {"type": "sodaCloudStorage", "fileId": self.soda_cloud_file_id}
         elif self.message:
             sample_ref_dict["reference"] = {"type": "noFile", "message": self.message, "link": self.link, "fileId": ""}
+            # TODO Replace above with the following when https://sodadata.atlassian.net/browse/CLOUD-2449 is done.
+            # sample_ref_dict["reference"] = {"type": "noFile",
+            #                                 "message": self.message,
+            #                                 "link": {"href": self.link, "text": self.link_text},
+            #                                 "fileId": ""}
 
         return sample_ref_dict
