@@ -79,6 +79,11 @@ class Scan:
             profile_table.get_dict()
             for profile_table in self._profile_columns_result_tables + self._sample_tables_result_tables
         ]
+
+        query_list = []
+        for query in self._queries:
+            query_list += query.get_cloud_dicts()
+
         return JsonHelper.to_jsonnable(  # type: ignore
             {
                 "definitionName": self._scan_definition_name,
@@ -92,8 +97,7 @@ class Scan:
                 "metrics": [metric.get_dict() for metric in self._metrics],
                 # If archetype is not None, it means that check is automated monitoring
                 "checks": checks,
-                # TODO Queries are not supported by Soda Cloud yet.
-                # "queries": [query.get_cloud_dict() for query in scan._queries],
+                "queries": query_list,
                 "automatedMonitoringChecks": automated_monitoring_checks,
                 "profiling": profiling,
                 "metadata": [
@@ -213,6 +217,27 @@ class Scan:
                 exception=e,
             )
 
+    def add_dask_dataframe(self, dataset_name: str, dask_df) -> None:
+        context = self._get_or_create_dask_context(required_soda_module="soda-core-pandas-dask")
+        context.create_table(dataset_name, dask_df)
+
+    def add_pandas_dataframe(self, dataset_name: str, pandas_df):
+        context = self._get_or_create_dask_context(required_soda_module="soda-core-pandas-dask")
+        from dask.dataframe import from_pandas
+
+        dask_df = from_pandas(pandas_df, npartitions=1)
+        context.create_table(dataset_name, dask_df)
+
+    def _get_or_create_dask_context(self, required_soda_module: str):
+        try:
+            from dask_sql import Context
+        except ImportError:
+            raise Exception(f"{required_soda_module} is not installed. Please install {required_soda_module}")
+
+        if "dask" not in self._configuration.data_source_properties_by_name:
+            self._configuration.add_dask_context(data_source_name="dask", dask_context=Context())
+        return self._configuration.data_source_properties_by_name["dask"]["context"]
+
     def add_sodacl_yaml_files(
         self,
         path: str,
