@@ -37,10 +37,12 @@ class SodaCloud:
         token: str | None,
         port: str | None,
         logs: Logs,
+        scheme: str = "https",
     ):
         self.host = host
         self.port = f":{port}" if port else ""
-        self.api_url = f"https://{self.host}{self.port}/api"
+        self.scheme = scheme if scheme else "https"
+        self.api_url = f"{self.scheme}://{self.host}{self.port}/api"
         self.api_key_id = api_key_id
         self.api_key_secret = api_key_secret
         self.token: str | None = token
@@ -81,6 +83,10 @@ class SodaCloud:
             for profile_table in scan._profile_columns_result_tables + scan._sample_tables_result_tables
         ]
 
+        query_list = []
+        for query in scan._queries:
+            query_list += query.get_cloud_dicts()
+
         return JsonHelper.to_jsonnable(  # type: ignore
             {
                 "definitionName": scan._scan_definition_name,
@@ -95,8 +101,7 @@ class SodaCloud:
                 "metrics": [metric.get_cloud_dict() for metric in scan._metrics],
                 # If archetype is not None, it means that check is automated monitoring
                 "checks": checks,
-                # TODO Queries are not supported by Soda Cloud yet.
-                # "queries": [query.get_cloud_dict() for query in scan._queries],
+                "queries": query_list,
                 "automatedMonitoringChecks": automated_monitoring_checks,
                 "profiling": profiling,
                 "metadata": [
@@ -271,7 +276,6 @@ class SodaCloud:
         )
 
     def _get_historic_measurements(self, hd: HistoricMeasurementsDescriptor):
-
         historic_measurements = self._execute_query(
             {
                 "type": "sodaCoreHistoricMeasurements",
